==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/WebColumnComponentEventArgsDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Description } from "./Description";
import { markType } from "./type";
/**
 * @hidden
 */
var WebColumnComponentEventArgsDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebColumnComponentEventArgsDescription, _super);
    function WebColumnComponentEventArgsDescription() {
        var _this = _super.call(this) || this;
        _this.f = null;
        return _this;
    }
    WebColumnComponentEventArgsDescription.prototype.get_type = function () {
        return "WebColumnComponentEventArgs";
    };
    Object.defineProperty(WebColumnComponentEventArgsDescription.prototype, "type", {
        get: function () {
            return this.get_type();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebColumnComponentEventArgsDescription.prototype, "detail", {
        get: function () {
            return this.f;
        },
        set: function (a) {
            this.f = a;
            this.e("Detail");
        },
        enumerable: true,
        configurable: true
    });
    WebColumnComponentEventArgsDescription.$t = markType(WebColumnComponentEventArgsDescription, 'WebColumnComponentEventArgsDescription', Description.$);
    WebColumnComponentEventArgsDescription.__marshalByValue = true;
    WebColumnComponentEventArgsDescription.__marshalByValueAlias = "ColumnComponentEventArgs";
    return WebColumnComponentEventArgsDescription;
}(Description));
export { WebColumnComponentEventArgsDescription };

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm5/lib/WebColumnComponentEventArgsDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Description } from "./Description";
import { markType } from "./type";
/**
 * @hidden
 */
var WebColumnComponentEventArgsDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebColumnComponentEventArgsDescription, _super);
    function WebColumnComponentEventArgsDescription() {
        var _this = _super.call(this) || this;
        _this.h = null;
        return _this;
    }
    WebColumnComponentEventArgsDescription.prototype.get_type = function () {
        return "WebColumnComponentEventArgs";
    };
    Object.defineProperty(WebColumnComponentEventArgsDescription.prototype, "type", {
        get: function () {
            return this.get_type();
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebColumnComponentEventArgsDescription.prototype, "detail", {
        get: function () {
            return this.h;
        },
        set: function (a) {
            this.h = a;
            this.g("Detail");
        },
        enumerable: false,
        configurable: true
    });
    WebColumnComponentEventArgsDescription.$t = markType(WebColumnComponentEventArgsDescription, 'WebColumnComponentEventArgsDescription', Description.$);
    WebColumnComponentEventArgsDescription.__marshalByValue = true;
    WebColumnComponentEventArgsDescription.__marshalByValueAlias = "ColumnComponentEventArgs";
    return WebColumnComponentEventArgsDescription;
}(Description));
export { WebColumnComponentEventArgsDescription };
